@@ -1,6 +1,8 @@
 #include <gtk/gtk.h>
 #include <sys/types.h>
+#ifndef WIN32
 #include <netinet/in.h>
+#endif
 
 #ifdef HAVE_NETSNMP
 #  include <net-snmp/net-snmp-config.h>
@@ -26,5 +28,6 @@ void on_instance_entry_changed(GtkEditable *editable,gpointer user_data);
 void on_value_entry_changed(GtkEditable *editable,gpointer user_data);
 void init_stuff(void);
 void disperror(const char *);
-void set_oid_entry(char *);
+void set_oid_entry(const char *);
 void need_to_exit(void);
+gboolean window_state_changed(GtkWidget *widget, GdkEventWindowState *event, gpointer user_data);
