@@ -1,14 +1,8 @@
 /*
  * configuration.c
  *
- * $Revision: 1.10 $
- *
  * Load and save configuration
  *
- * Last Modified:
- *  $Author: ahodgen $
- *  $Date: 2003/02/22 16:59:56 $
- *
  */
 
 #ifdef HAVE_CONFIG_H
@@ -25,43 +19,36 @@
 #include "interface.h"
 #include "callbacks.h"
 #include "mibtree.h"
+#include "os.h"
 
-#define CONFIG_FILE 	"/.mbrowse"
+#define CONFIG_FILE 	PATH_SEPARATOR ".mbrowse"
 #define CREAT_ERR	"Error creating "/**/CONFIG_FILE
 #define BLANK		""
 
-static int exp_cir = GTK_CTREE_EXPANDER_CIRCULAR;
-static int exp_tri = GTK_CTREE_EXPANDER_TRIANGLE;
-static int exp_non = GTK_CTREE_EXPANDER_NONE;
-static int exp_squ = GTK_CTREE_EXPANDER_SQUARE;
+static int wrap_none = GTK_WRAP_NONE;
+static int wrap_char = GTK_WRAP_CHAR;
+static int wrap_word = GTK_WRAP_WORD;
+static int wrap_word_char = GTK_WRAP_WORD_CHAR;
 
-#define MAX_EXPANDER  	(GTK_CTREE_EXPANDER_CIRCULAR | \
-			GTK_CTREE_EXPANDER_TRIANGLE | \
-			GTK_CTREE_EXPANDER_NONE | \
-			GTK_CTREE_EXPANDER_SQUARE)+1
-
-#define MAX_LINE	(GTK_CTREE_LINES_NONE | \
-			GTK_CTREE_LINES_SOLID | \
-			GTK_CTREE_LINES_DOTTED | \
-			GTK_CTREE_LINES_TABBED)+1
+#define MAX_WRAPPING	(GTK_WRAP_NONE | \
+			GTK_WRAP_CHAR | \
+			GTK_WRAP_WORD | \
+			GTK_WRAP_WORD_CHAR)+1
 
 #define MAX_SNMP_VER	(SNMP_VERSION_1 | SNMP_VERSION_2c)+1
 
-extern GdkPixmap *table_xpm;   
-extern GdkBitmap *table_mask;
-extern GdkPixmap *child_xpm; 
-extern GdkBitmap *child_mask;
-extern GdkPixmap *end_xpm;   
-extern GdkBitmap *end_mask;  
+extern GdkPixbuf *child_pixbuf;
+extern GdkPixbuf *end_pixbuf;
 
-static GtkWidget *expanders[MAX_EXPANDER];
-static GtkWidget *lines[MAX_LINE];
+static GtkWidget *wrappings[MAX_WRAPPING];
 static GtkWidget *snmp_ver[MAX_SNMP_VER];
-static GtkWidget *test_ctree;
+static GtkWidget *test_tree;
 static GtkWidget *snmp_port_entry;
 static GtkWidget *save_sess_button;
+static GtkWidget *save_window_size_button;
 static GtkWidget *snmp_to_spin;
 static GtkWidget *snmp_retry_spin;
+static GtkWidget *line_show_butt;
 
 union types {
   char *string;
@@ -92,20 +79,21 @@ config_opt_t config_opts[] = {
   { "snmp_timeout", INTEGER,{integer:2},&config.snmp_timeout },
   { "snmp_reties",  INTEGER,{integer:1},&config.snmp_retries },
   { "snmp_port",    INTEGER,{integer:161},&config.snmp_port },
-  { "tree_expander",INTEGER,{integer:GTK_CTREE_EXPANDER_SQUARE},&config.tree_expander },
-  { "tree_line",    INTEGER,{integer:GTK_CTREE_LINES_SOLID},&config.tree_line },
+  { "tree_line",    INTEGER,{integer:1},&config.tree_line },
+  { "out_wrap_mode",INTEGER,{integer:GTK_WRAP_NONE},&config.out_wrap_mode },
+  { "save_window_size", INTEGER, {integer:1}, &config.save_window_size },
+  { "window_width", INTEGER, {integer:-1}, &config.window_width },
+  { "window_height", INTEGER, {integer:-1}, &config.window_height },
+  { "window_maximized", INTEGER, {integer:0}, &config.window_maximized },
   { NULL,           INTEGER, {integer:0},NULL },
 };
 
-void set_expand_style(GtkWidget *widget,gpointer data);
-void set_line_style(GtkWidget *widget,gpointer data);
-
 config_t *get_config() {
 
   return(&config);
 }
 
-void set_defaults(void) {
+static void set_defaults(void) {
 
   config_opt_t *c;
 
@@ -124,16 +112,17 @@ void set_defaults(void) {
   }
 };
 
-void apply_config(void) {
+static void apply_config(void) {
 
   char port[10];
   /* Set entries in the options tab */
 
 
-  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(expanders[config.tree_expander]),TRUE);
-  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(lines[config.tree_line]),TRUE);
+  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(line_show_butt),config.tree_line);
+  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(wrappings[config.out_wrap_mode]),TRUE);
 
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(save_sess_button),config.save_sess);
+  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(save_window_size_button),config.save_window_size);
 
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(snmp_ver[config.snmp_ver]),TRUE);
   gtk_spin_button_set_value(GTK_SPIN_BUTTON(snmp_to_spin),(gfloat) config.snmp_timeout);
@@ -149,6 +138,14 @@ void apply_config(void) {
   set_hostname(config.host);
   set_instance(config.inst);
   set_value(config.value);
+  if (config.save_window_size) {
+    if ((config.window_width != -1) && (config.window_height != -1)) {
+      set_window_size(config.window_width, config.window_height);
+    }
+    if (config.window_maximized) {
+      set_window_maximized();
+    }
+  }
 }
 
 void load_config(void) {
@@ -163,7 +160,11 @@ void load_config(void) {
   int state;
   int lineno = 0;
 
+#ifdef WIN32
+  strncpy(line,".\\",1023); /* FIXME: hack */
+#else
   strncpy(line,getenv("HOME"),1023);
+#endif
   strncat(line,CONFIG_FILE,(1023-strlen(line)));
   set_defaults();
   if((fp = fopen(line,"r")) == NULL) {
@@ -235,9 +236,22 @@ void save_config(void) {
   config.inst = get_instance();
   config.value = get_value();
 
+  if (config.save_window_size) {
+    get_window_size(&config.window_width, &config.window_height);
+  } else {
+    /* Discard any previous values. */
+    config.window_width = -1;
+    config.window_height = -1;
+    config.window_maximized = 0;
+  }
+
   if(config.save_sess == FALSE)
     return;
+#ifdef WIN32
+  strncpy(file,".\\",1023); /* FIXME: hack */
+#else
   strncpy(file,getenv("HOME"),1023);
+#endif
   strncat(file,CONFIG_FILE,(1023-strlen(file)));
   if((fp = fopen(file,"w")) == NULL) {
     perror(CREAT_ERR);
@@ -263,46 +277,41 @@ void save_config(void) {
   chmod(CONFIG_FILE,S_IWUSR | S_IRUSR);
 }
 
-void set_expand_style(GtkWidget *widget,gpointer data ) {
+static void show_line_toggled(GtkWidget *widget,gpointer data ) {
 
-  if (widget)
-    if (!gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget)))
-      return;
-  config.tree_expander = *(int *)data;
-  gtk_ctree_set_expander_style(GTK_CTREE(test_ctree),(int)data);
+  config.tree_line = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget));
+  gtk_tree_view_set_enable_tree_lines(GTK_TREE_VIEW(test_tree), config.tree_line);
   set_mibtree_style(config.tree_expander,config.tree_line);
 }
 
-void set_line_style(GtkWidget *widget,gpointer data ) {
+static void set_snmp_version(GtkWidget *widget,gpointer data) {
 
-  if (widget)
-    if (!gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget)))
-      return;
-  config.tree_line =(int) data;
-  gtk_ctree_set_line_style(GTK_CTREE(test_ctree),(int)data);
-  set_mibtree_style(config.tree_expander,config.tree_line);
+  config.snmp_ver = (long) data;
 }
 
-void set_snmp_version(GtkWidget *widget,gpointer data) {
-
-  config.snmp_ver = (int) data;
-}
-
-void set_timeout(GtkWidget *widget,GtkWidget *data) {
+static void set_timeout(GtkWidget *widget,GtkWidget *data) {
 
   config.snmp_timeout = gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(data));
 }
 
-void set_retries(GtkWidget *widget,GtkWidget *data) {
+static void set_retries(GtkWidget *widget,GtkWidget *data) {
 
   config.snmp_retries = gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(data));
 }
-void set_port(GtkWidget *widget,GtkWidget *data) {
+static void set_port(GtkWidget *widget,GtkWidget *data) {
 
   config.snmp_port = atoi(gtk_entry_get_text(GTK_ENTRY(data)));
 }
 
-void save_sess_toggled(GtkButton *button,gpointer user_data) {
+static void set_out_wrap_mode(GtkWidget *widget,GtkWidget *data) {
+  if (widget)
+    if (!gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget)))
+      return;
+  config.out_wrap_mode = *(int *)data;
+  set_out_box_wrap_mode(config.out_wrap_mode);
+}
+
+static void save_sess_toggled(GtkButton *button,gpointer user_data) {
 
   FILE *fp;
   char file[1024];
@@ -311,7 +320,11 @@ void save_sess_toggled(GtkButton *button,gpointer user_data) {
     config.save_sess = TRUE;
   else {
     config.save_sess = FALSE;
+#ifdef WIN32
+    strncpy(file,".\\",1023); /* FIXME: hack */
+#else
     strncpy(file,getenv("HOME"),1023);
+#endif
     strncat(file,CONFIG_FILE,(1023-strlen(file)));
     if((fp = fopen(file,"w")) == NULL) {
       perror(CREAT_ERR);
@@ -322,16 +335,23 @@ void save_sess_toggled(GtkButton *button,gpointer user_data) {
   }
 }
 
+static void save_window_size_toggled(GtkButton *button, gpointer user_data) {
+  config.save_window_size = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(button));
+}
+
 void create_config_tab(int tab_pos) {
 
   GtkWidget *option_vbox;
   GtkWidget *general_frame;
+  GtkWidget *wrapping_frame;
   GtkWidget *snmp_config_frame;
+  GtkWidget *general_frame_vbox;
   GtkWidget *snmp_config_hbox;
   GtkWidget *snmp_ver_vbox;
   GtkWidget *snmp_ver_label;
   GtkWidget *hbox2;
   GSList *snmp_ver_group = NULL;
+  GtkWidget *hbox3;
   GtkWidget *snmp_to_vbox;
   GtkWidget *timeout_label;
   GtkWidget *snmp_to_hbox;
@@ -344,25 +364,22 @@ void create_config_tab(int tab_pos) {
   GtkWidget *snmp_port_label;
   GtkWidget *tree_style_frame;
   GtkWidget *tree_style_hbox;
-  GtkWidget *expand_vbox;
-  GtkWidget *expand_label;
-  GSList *expanders_group = NULL;
-  GtkWidget *expand_none_butt;
-  GtkWidget *expand_square_butt;
-  GtkWidget *expand_triangle_butt;
-  GtkWidget *expand_circle_butt;
-  GtkWidget *line_vbox;
-  GtkWidget *line_label;
-  GSList *line_group = NULL;
-  GtkWidget *line_none_butt;
-  GtkWidget *line_solid_butt;
-  GtkWidget *line_dotted_butt;
-  GtkWidget *line_tabbed_butt;
+  GtkWidget *wrapping_vbox;
+  GSList *wrapping_group = NULL;
+  GtkWidget *wrapping_none_butt;
+  GtkWidget *wrapping_char_butt;
+  GtkWidget *wrapping_word_butt;
+  GtkWidget *wrapping_word_char_butt;
   GtkWidget *config_tab;
   GtkWidget *hbox1;
-  GtkCTreeNode *subtree;
   GtkWidget *notebook;
-  gchar *label[1];
+  GtkTreeViewColumn *tree_col;
+  GtkCellRenderer *tree_renderer1;
+  GtkCellRenderer *tree_renderer2;
+  GtkTreeStore *tree_store;
+  GtkTreeIter tree_parent;
+  GtkTreeIter tree_child;
+  GtkTreeIter tree_end;
 
   notebook = get_main_widgets()->notebook;
   option_vbox = gtk_vbox_new(FALSE,0);
@@ -373,17 +390,36 @@ void create_config_tab(int tab_pos) {
   gtk_widget_show(hbox1);
   gtk_box_pack_start(GTK_BOX(option_vbox),hbox1,FALSE,TRUE,0);
 
+  hbox3 = gtk_hbox_new(FALSE,0);
+  gtk_widget_show(hbox3);
+  gtk_box_pack_start(GTK_BOX(option_vbox),hbox3,FALSE,TRUE,0);
+
+  wrapping_frame = gtk_frame_new("Output wrapping");
+  gtk_widget_show(wrapping_frame);
+  gtk_box_pack_start(GTK_BOX(hbox3),wrapping_frame,FALSE,TRUE,5);
+  gtk_container_set_border_width(GTK_CONTAINER(wrapping_frame),5);
+
   general_frame = gtk_frame_new("General");
   gtk_widget_show(general_frame);
   gtk_box_pack_start(GTK_BOX(hbox1),general_frame,FALSE,TRUE,0);
   gtk_container_set_border_width(GTK_CONTAINER(general_frame),5);
 
+  general_frame_vbox = gtk_vbox_new(FALSE, 0);
+  gtk_widget_show(general_frame_vbox);
+  gtk_container_add(GTK_CONTAINER(general_frame), general_frame_vbox);
+
   save_sess_button = gtk_check_button_new_with_label("Save session on exit");
   gtk_widget_show(save_sess_button);
-  gtk_container_add(GTK_CONTAINER(general_frame),save_sess_button);
-  gtk_signal_connect_after(GTK_OBJECT(save_sess_button),"clicked",
+  gtk_box_pack_start(GTK_BOX(general_frame_vbox), save_sess_button, FALSE, FALSE, 0);
+  gtk_signal_connect_after(GTK_OBJECT(save_sess_button),"toggled",
                            GTK_SIGNAL_FUNC(save_sess_toggled),NULL);
 
+  save_window_size_button = gtk_check_button_new_with_label("Save window size");
+  gtk_widget_show(save_window_size_button);
+  gtk_box_pack_start(GTK_BOX(general_frame_vbox), save_window_size_button, FALSE, FALSE, 0);
+  gtk_signal_connect_after(GTK_OBJECT(save_window_size_button),"toggled",
+                           GTK_SIGNAL_FUNC(save_window_size_toggled),NULL);
+
 
   snmp_config_frame = gtk_frame_new("SNMP Configuration");
   gtk_widget_show(snmp_config_frame);
@@ -430,7 +466,7 @@ void create_config_tab(int tab_pos) {
   gtk_widget_show(snmp_to_hbox);
   gtk_box_pack_start(GTK_BOX(snmp_to_vbox),snmp_to_hbox,FALSE,FALSE,0);
 
-  snmp_to_spin_adj = gtk_adjustment_new(1,0,100,1,10,10);
+  snmp_to_spin_adj = gtk_adjustment_new(1,0,100,1,10,0);
   snmp_to_spin = gtk_spin_button_new(GTK_ADJUSTMENT(snmp_to_spin_adj),1,0);
   gtk_widget_show(snmp_to_spin);
   gtk_box_pack_start(GTK_BOX(snmp_to_hbox),snmp_to_spin,TRUE,TRUE,0);
@@ -450,7 +486,7 @@ void create_config_tab(int tab_pos) {
   gtk_widget_show(snmp_retry_label);
   gtk_box_pack_start(GTK_BOX(snmp_retry_vbox),snmp_retry_label,FALSE,FALSE,0);
 
-  snmp_retry_spin_adj = gtk_adjustment_new(1,0,100,1,10,10);
+  snmp_retry_spin_adj = gtk_adjustment_new(1,0,100,1,10,0);
   snmp_retry_spin = gtk_spin_button_new(GTK_ADJUSTMENT(snmp_retry_spin_adj),1,0);
   gtk_widget_show(snmp_retry_spin);
   gtk_box_pack_start(GTK_BOX(snmp_retry_vbox),snmp_retry_spin,FALSE,FALSE,0);
@@ -476,105 +512,77 @@ void create_config_tab(int tab_pos) {
 
   tree_style_frame = gtk_frame_new("Tree Style");
   gtk_widget_show(tree_style_frame);
-  gtk_box_pack_start(GTK_BOX(option_vbox),tree_style_frame,FALSE,TRUE,0);
+  gtk_box_pack_start(GTK_BOX(hbox3),tree_style_frame,TRUE,TRUE,0);
   gtk_container_set_border_width(GTK_CONTAINER(tree_style_frame),5);
 
   tree_style_hbox = gtk_hbox_new(FALSE,0);
   gtk_widget_show(tree_style_hbox);
   gtk_container_add(GTK_CONTAINER(tree_style_frame),tree_style_hbox);
 
-  expand_vbox = gtk_vbox_new(FALSE,0);
-  gtk_widget_show(expand_vbox);
-  gtk_box_pack_start(GTK_BOX(tree_style_hbox),expand_vbox,FALSE,TRUE,0);
+  wrapping_vbox = gtk_vbox_new(FALSE,0);
+  gtk_widget_show(wrapping_vbox);
+  gtk_container_add(GTK_CONTAINER(wrapping_frame),wrapping_vbox);
 
-  expand_label = gtk_label_new("Expanders");
-  gtk_widget_show(expand_label);
-  gtk_box_pack_start(GTK_BOX(expand_vbox),expand_label,FALSE,FALSE,0);
+  wrapping_none_butt = gtk_radio_button_new_with_label(wrapping_group,"None");
+  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(wrapping_none_butt),TRUE);
+  wrappings[GTK_WRAP_NONE] = wrapping_none_butt;
+  wrapping_group = gtk_radio_button_group(GTK_RADIO_BUTTON(wrapping_none_butt));
+  gtk_widget_show(wrapping_none_butt);
+  gtk_box_pack_start(GTK_BOX(wrapping_vbox),wrapping_none_butt,FALSE,FALSE,0);
+  gtk_signal_connect(GTK_OBJECT(wrapping_none_butt),"clicked",GTK_SIGNAL_FUNC(set_out_wrap_mode),&wrap_none);
 
-  expand_none_butt = gtk_radio_button_new_with_label(expanders_group,"None");
-  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(expand_none_butt),TRUE);
-  expanders[GTK_CTREE_EXPANDER_NONE] = expand_none_butt;
-  expanders_group = gtk_radio_button_group(GTK_RADIO_BUTTON(expand_none_butt));
-  gtk_widget_show(expand_none_butt);
-  gtk_box_pack_start(GTK_BOX(expand_vbox),expand_none_butt,FALSE,FALSE,0);
-  gtk_signal_connect(GTK_OBJECT(expand_none_butt),"clicked",GTK_SIGNAL_FUNC(set_expand_style),&exp_non);
+  wrapping_char_butt = gtk_radio_button_new_with_label(wrapping_group,"Characters");
+  wrappings[GTK_WRAP_CHAR] = wrapping_char_butt;
+  wrapping_group = gtk_radio_button_group(GTK_RADIO_BUTTON(wrapping_char_butt));
+  gtk_widget_show(wrapping_char_butt);
+  gtk_box_pack_start(GTK_BOX(wrapping_vbox),wrapping_char_butt,FALSE,FALSE,0);
+  gtk_signal_connect(GTK_OBJECT(wrapping_char_butt),"clicked",GTK_SIGNAL_FUNC(set_out_wrap_mode),&wrap_char);
 
-  expand_square_butt = gtk_radio_button_new_with_label(expanders_group,"Square");
-  expanders[GTK_CTREE_EXPANDER_SQUARE] = expand_square_butt;
-  expanders_group = gtk_radio_button_group(GTK_RADIO_BUTTON(expand_square_butt));
-  gtk_widget_show(expand_square_butt);
-  gtk_box_pack_start(GTK_BOX(expand_vbox),expand_square_butt,FALSE,FALSE,0);
-  gtk_signal_connect(GTK_OBJECT(expand_square_butt),"clicked",GTK_SIGNAL_FUNC(set_expand_style),&exp_squ);
+  wrapping_word_butt = gtk_radio_button_new_with_label(wrapping_group,"Words");
+  wrappings[GTK_WRAP_WORD] = wrapping_word_butt;
+  wrapping_group = gtk_radio_button_group(GTK_RADIO_BUTTON(wrapping_word_butt));
+  gtk_widget_show(wrapping_word_butt);
+  gtk_box_pack_start(GTK_BOX(wrapping_vbox),wrapping_word_butt,FALSE,FALSE,0);
+  gtk_signal_connect(GTK_OBJECT(wrapping_word_butt),"clicked",GTK_SIGNAL_FUNC(set_out_wrap_mode),&wrap_word);
 
-  expand_triangle_butt = gtk_radio_button_new_with_label(expanders_group,"Triangle");
-  expanders[GTK_CTREE_EXPANDER_TRIANGLE] = expand_triangle_butt;
-  expanders_group = gtk_radio_button_group(GTK_RADIO_BUTTON(expand_triangle_butt));
-  gtk_widget_show(expand_triangle_butt);
-  gtk_box_pack_start(GTK_BOX(expand_vbox),expand_triangle_butt,FALSE,FALSE,0);
-  gtk_signal_connect(GTK_OBJECT(expand_triangle_butt),"clicked",GTK_SIGNAL_FUNC(set_expand_style),&exp_tri);
+  wrapping_word_char_butt = gtk_radio_button_new_with_label(wrapping_group,"Words then Characters");
+  wrappings[GTK_WRAP_WORD_CHAR] = wrapping_word_char_butt;
+  wrapping_group = gtk_radio_button_group(GTK_RADIO_BUTTON(wrapping_word_char_butt));
+  gtk_widget_show(wrapping_word_char_butt);
+  gtk_box_pack_start(GTK_BOX(wrapping_vbox),wrapping_word_char_butt,FALSE,FALSE,0);
+  gtk_signal_connect(GTK_OBJECT(wrapping_word_char_butt),"clicked",GTK_SIGNAL_FUNC(set_out_wrap_mode),&wrap_word_char);
 
-  expand_circle_butt = gtk_radio_button_new_with_label(expanders_group,"Circle");
-  expanders[GTK_CTREE_EXPANDER_CIRCULAR] = expand_circle_butt;
-  expanders_group = gtk_radio_button_group(GTK_RADIO_BUTTON(expand_circle_butt));
-  gtk_widget_show(expand_circle_butt);
-  gtk_box_pack_start(GTK_BOX(expand_vbox),expand_circle_butt,FALSE,FALSE,0);
-  gtk_signal_connect(GTK_OBJECT(expand_circle_butt),"clicked",GTK_SIGNAL_FUNC(set_expand_style),&exp_cir);
+  line_show_butt = gtk_check_button_new_with_label("Show lines");
+  gtk_widget_show(line_show_butt);
+  gtk_box_pack_start(GTK_BOX(tree_style_hbox),line_show_butt,FALSE,FALSE,0);
+  gtk_signal_connect(GTK_OBJECT(line_show_butt),"toggled",GTK_SIGNAL_FUNC(show_line_toggled),NULL);
 
-  line_vbox = gtk_vbox_new(FALSE,0);
-  gtk_widget_show(line_vbox);
-  gtk_box_pack_start(GTK_BOX(tree_style_hbox),line_vbox,FALSE,FALSE,0);
+  test_tree = gtk_tree_view_new();
+  gtk_widget_show(test_tree);
+  gtk_tree_view_set_headers_visible(GTK_TREE_VIEW(test_tree), FALSE);
+  gtk_box_pack_start(GTK_BOX(tree_style_hbox),test_tree,TRUE,TRUE,0);
 
-  line_label = gtk_label_new("Line");
-  gtk_widget_show(line_label);
-  gtk_box_pack_start(GTK_BOX(line_vbox),line_label,FALSE,FALSE,0);
+  tree_col = gtk_tree_view_column_new();
+  gtk_tree_view_append_column(GTK_TREE_VIEW(test_tree), tree_col);
+  tree_renderer1 = gtk_cell_renderer_pixbuf_new();
+  gtk_tree_view_column_pack_start(tree_col, tree_renderer1, FALSE);
+  gtk_tree_view_column_add_attribute(tree_col, tree_renderer1, "pixbuf", 0);
 
-  line_none_butt = gtk_radio_button_new_with_label(line_group,"None");
-  lines[GTK_CTREE_LINES_NONE] = line_none_butt;
-  line_group = gtk_radio_button_group(GTK_RADIO_BUTTON(line_none_butt));
-  gtk_widget_show(line_none_butt);
-  gtk_box_pack_start(GTK_BOX(line_vbox),line_none_butt,FALSE,FALSE,0);
-  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(line_none_butt),TRUE);
-  gtk_signal_connect(GTK_OBJECT(line_none_butt),"clicked",GTK_SIGNAL_FUNC(set_line_style),(gpointer)GTK_CTREE_LINES_NONE);
+  tree_renderer2 = gtk_cell_renderer_text_new();
+  gtk_tree_view_column_pack_start(tree_col, tree_renderer2, TRUE);
+  gtk_tree_view_column_add_attribute(tree_col, tree_renderer2, "text", 1);
 
-  line_solid_butt = gtk_radio_button_new_with_label(line_group,"Solid");
-  lines[GTK_CTREE_LINES_SOLID] = line_solid_butt;
-  line_group = gtk_radio_button_group(GTK_RADIO_BUTTON(line_solid_butt));
-  gtk_widget_show(line_solid_butt);
-  gtk_box_pack_start(GTK_BOX(line_vbox),line_solid_butt,FALSE,FALSE,0);
-  gtk_signal_connect(GTK_OBJECT(line_solid_butt),"clicked",GTK_SIGNAL_FUNC(set_line_style),(gpointer)GTK_CTREE_LINES_SOLID);
+  tree_store = gtk_tree_store_new(2, GDK_TYPE_PIXBUF, G_TYPE_STRING);
 
-  line_dotted_butt = gtk_radio_button_new_with_label(line_group,"Dotted");
-  lines[GTK_CTREE_LINES_DOTTED] = line_dotted_butt;
-  line_group = gtk_radio_button_group(GTK_RADIO_BUTTON(line_dotted_butt));
-  gtk_widget_show(line_dotted_butt);
-  gtk_box_pack_start(GTK_BOX(line_vbox),line_dotted_butt,FALSE,FALSE,0);
-  gtk_signal_connect(GTK_OBJECT(line_dotted_butt),"clicked",GTK_SIGNAL_FUNC(set_line_style),(gpointer)GTK_CTREE_LINES_DOTTED);
+  gtk_tree_store_append(tree_store, &tree_parent, NULL);
+  gtk_tree_store_set(tree_store, &tree_parent, 0, child_pixbuf, 1, "Parent", -1);
+  gtk_tree_store_append(tree_store, &tree_child, &tree_parent);
+  gtk_tree_store_set(tree_store, &tree_child, 0, child_pixbuf, 1, "Child", -1);
+  gtk_tree_store_append(tree_store, &tree_end, &tree_child);
+  gtk_tree_store_set(tree_store, &tree_end, 0, end_pixbuf, 1, "Leaf", -1);
 
-  line_tabbed_butt = gtk_radio_button_new_with_label(line_group,"Tabbed");
-  lines[GTK_CTREE_LINES_TABBED] = line_tabbed_butt;
-  line_group = gtk_radio_button_group(GTK_RADIO_BUTTON(line_tabbed_butt));
-  gtk_widget_show(line_tabbed_butt);
-  gtk_box_pack_start(GTK_BOX(line_vbox),line_tabbed_butt,FALSE,FALSE,0);
-  gtk_signal_connect(GTK_OBJECT(line_tabbed_butt),"clicked",GTK_SIGNAL_FUNC(set_line_style),(gpointer)GTK_CTREE_LINES_TABBED);
-
-  test_ctree = gtk_ctree_new(1,0);
-  gtk_widget_show(test_ctree);
-  gtk_box_pack_start(GTK_BOX(tree_style_hbox),test_ctree,TRUE,TRUE,0);
-  gtk_clist_column_titles_hide(GTK_CLIST(test_ctree));
-
-  label[0] = "Parent";
-  subtree = gtk_ctree_insert_node(GTK_CTREE(test_ctree),NULL,NULL,
-				label,5,child_xpm,child_mask,child_xpm,child_mask,
-                                FALSE,TRUE);
-  label[0] = "Child";
-  subtree = gtk_ctree_insert_node(GTK_CTREE(test_ctree),GTK_CTREE_NODE(subtree),NULL,
-				label,5,child_xpm,child_mask,child_xpm,child_mask,
-				FALSE,TRUE);
-  label[0] = "Leaf";
-  subtree = gtk_ctree_insert_node(GTK_CTREE(test_ctree),GTK_CTREE_NODE(subtree),NULL,
-				label,5,end_xpm,end_mask,end_xpm,end_mask,
-				TRUE,TRUE);
-  gtk_clist_set_column_width (GTK_CLIST(test_ctree),0,10);
+  gtk_tree_view_set_model(GTK_TREE_VIEW(test_tree), GTK_TREE_MODEL(tree_store));
+  gtk_tree_view_expand_all(GTK_TREE_VIEW(test_tree));
 
   config_tab = gtk_label_new("Options");
   gtk_widget_show(config_tab);
