@@ -1,10 +1,10 @@
 typedef struct {
-  char *oid;
-  char *readcomm;
-  char *writecomm;
-  char *host;
-  char *inst;
-  char *value;
+  const char *oid;
+  const char *readcomm;
+  const char *writecomm;
+  const char *host;
+  const char *inst;
+  const char *value;
   int  save_sess;
   int  snmp_ver;
   int  snmp_timeout;
@@ -12,6 +12,11 @@ typedef struct {
   int  snmp_port;
   int  tree_expander;
   int  tree_line;
+  GtkWrapMode out_wrap_mode;
+  int  save_window_size;
+  int  window_width;
+  int  window_height;
+  int  window_maximized;
 } config_t;
 
 config_t *get_config(void);
