@@ -14,4 +14,4 @@ typedef struct {
 
 void create_detail_tab(void);
 void populate_detail_tab(struct tree *node);
-char *find_val_from_enum(char *label);
+const char *find_val_from_enum(const char *label);
